==> xlog-0.9.6.tar.gz: xlog-0.9.6/src/utils.h <==
/*
 * xlog - GTK+ logging program for amateur radio operators
 * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * utils.h
 */

gchar *setlocation (gdouble lat, gint NS, gdouble lon, gint EW);
void updateoptionmenu (GtkWidget * optionmenu, gchar ** split);
void deletespaces (gchar ** split);
void update_statusbar (gchar * string);
gboolean remove_prefixes (gchar * key, gpointer value, gpointer user_data);
void save_windowsize_and_cleanup (void);
gchar *finddot (gchar * qsoband);
gchar *findint (gchar * freq);
gchar *findband (gchar * arg);
gchar *getdate (void);
gchar *gettime (void);
gchar *lookup_mode (gchar * selectedmode);
gchar *lookup_band (gchar * selectedband);
gint updateclock (void);
gchar *color_parse (gchar * value);
gchar *getlabelcolor (GtkWidget * label);
gint autosave (void);
void set_qsoframe (gpointer arg);
gboolean fileexist (gchar * path);
gchar *my_strreplace(gchar *str, const gchar *from, const gchar *to);

==> xlog_1.0.tar.gz: xlog-1.0/src/utils.h <==
/*
 * xlog - GTK+ logging program for amateur radio operators
 * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * utils.h
 */

gchar *setlocation (gdouble lat, gint NS, gdouble lon, gint EW);
void makebandoptionmenu (gchar *bands);
void makemodeoptionmenu (gchar *modes);
void deletespaces (gchar ** split);
void update_statusbar (gchar * string);
gboolean remove_prefixes (gchar * key, gpointer value, gpointer user_data);
void save_windowsize_and_cleanup (void);
gchar *finddot (gchar * qsoband);
gchar *findint (gchar * freq);
gchar *findband (gchar * arg);
gchar *getdate (void);
gchar *gettime (void);
gchar *lookup_mode (gint index);
gchar *lookup_band (gint index);
gint updateclock (void);
gchar *color_parse (gchar * value);
gchar *getlabelcolor (GtkWidget * label);
gint autosave (void);
void set_qsoframe (gpointer arg);
gboolean fileexist (gchar * path);
gchar *my_strreplace(gchar *str, const gchar *from, const gchar *to);
